//
//  ViewController.m
//  Uart_BLE
//
//  Created by lc on 14-6-4.
//
//

#import "ViewController.h"

@interface ViewController ()

@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    
    //初始化数组
    deviceArray = [[NSMutableArray alloc] init];
    deviceUUIDArray = [[NSMutableArray alloc] init];
    
    //tableview中间分割线从最左边画到最右边
    UIEdgeInsets edgeInset = self.tableView.separatorInset;
    self.tableView.separatorInset = UIEdgeInsetsMake(edgeInset.top, 0, edgeInset.bottom, edgeInset.right);
    self.tableView.separatorStyle = UITableViewCellSeparatorStyleSingleLine;
    
    //初始化需要push的ViewController
    subVC = [self.storyboard instantiateViewControllerWithIdentifier:@"sub"];
    
    //初始化导航栏左边按钮和返回按钮
    UIImage *itonLogo = [UIImage imageNamed:@"iton.png"];
    UIImageView *imageView = [[UIImageView alloc] initWithFrame:CGRectMake(0, 0, itonLogo.size.width, itonLogo.size.height)];
    imageView.image = itonLogo;
    UIBarButtonItem *leftItem = [[UIBarButtonItem alloc] initWithCustomView:imageView];
    self.navigationItem.leftBarButtonItem = leftItem;
    
    UIBarButtonItem *backItem = [[UIBarButtonItem alloc] initWithImage:itonLogo style:UIBarButtonItemStyleBordered target:subVC action:@selector(popViewControllerAnimated:)];
    self.navigationItem.backBarButtonItem = backItem;
    
    //搜索设备时候的转圈控件
    loadView = [[UIActivityIndicatorView alloc] initWithFrame:CGRectMake(238, 27, 30, 30)];
    [loadView setActivityIndicatorViewStyle:UIActivityIndicatorViewStyleGray];
    [loadView startAnimating];
    [self.navigationController.view addSubview:loadView];
    [loadView setHidden:YES];
    
    //初始化设备实例
    uart = [[BLEDevice_UART alloc] init:self];
}

- (void)viewDidAppear:(BOOL)animated
{
    //pop回来之后会执行的操作:断开设备连接,移除所有项,重新开始搜索设备
    [uart BD_disConnect];
    
    [self ClearTableViewData];
    [self ScanDevice];
    tmr_ScanDevice = [NSTimer scheduledTimerWithTimeInterval:2.0f target:self selector:@selector(ScanDevice) userInfo:nil repeats:YES];
    [loadView setHidden:NO];
    rightBarButton.title = @"Stop";
}

- (void)viewDidDisappear:(BOOL)animated
{
    [tmr_ScanDevice invalidate];
    tmr_ScanDevice = nil;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark -
#pragma mark - Private Method
//开始搜索按钮点击事件(和停止搜索是同一个)
- (IBAction)StartScan:(id)sender
{
    if ([rightBarButton.title isEqualToString:@"Start"])
    {
        [self ScanDevice];
        tmr_ScanDevice = [NSTimer scheduledTimerWithTimeInterval:2.0f target:self selector:@selector(ScanDevice) userInfo:nil repeats:YES];
        [loadView setHidden:NO];
        rightBarButton.title = @"Stop";
        
    }
    else if ([rightBarButton.title isEqualToString:@"Stop"])
    {
        [tmr_ScanDevice invalidate];
        tmr_ScanDevice = nil;
        [loadView setHidden:YES];
        [self ClearTableViewData];
        rightBarButton.title = @"Start";
    }
}

//获取设备列表
- (void)ScanDevice
{
    [uart BD_getScanDeviceList:3.0f];
}

//清除所有tableview数据
- (void)ClearTableViewData
{
    [deviceArray removeAllObjects];
    [deviceUUIDArray removeAllObjects];
    [self.tableView reloadData];
}

//移除数组中的重复项
- (NSArray *)RemoveDuplicateDataFromArray:(NSArray *)arrayA
{
    if (!arrayA)
    {
        return nil;
    }
    NSMutableArray *arrayB = [NSMutableArray new];
    arrayB[0] = arrayA[0];
    for (int i = 1; i < arrayA.count; i++)
    {
        for (int j = 0; j < arrayB.count; j++)
        {
            if ([arrayA[i] isEqualToString:arrayB[j]])
            {
                break;
            }
            
            if (j == arrayB.count - 1 && arrayA[i] != arrayB[j]) {
                [arrayB addObject:arrayA[i]];
            }
        }
    }
    
    return arrayB;
}

#pragma mark - Protocol_BLEDeviceResult Method
//获取到的设备列表回调
-(void)BR_scanDeviceList:(NSMutableArray *)arrayScanDeviceList;
{
    if (arrayScanDeviceList.count < 1)
    {
        return;
    }
    [deviceArray removeAllObjects];
    [deviceUUIDArray removeAllObjects];
    for (int i = 0; i < arrayScanDeviceList.count; i++)
    {
        [deviceArray addObject:[[arrayScanDeviceList[i] componentsSeparatedByString:@","] objectAtIndex:0]];
        [deviceUUIDArray addObject:[[arrayScanDeviceList[i] componentsSeparatedByString:@","] objectAtIndex:2]];
    }
    [self.tableView reloadData];
}

//硬件数据接受函数
-(void)BR_receiveBaseData:(Byte*)bytes length:(int)length recvTime:(NSDate *)recvTime
{
    [subVC ReceiveData:bytes length:length recvTime:recvTime];
}

//连接成功回调
- (void)BR_connectOK
{
    [tmr_ScanDevice invalidate];
    tmr_ScanDevice = nil;
    [loadView setHidden:YES];
    subVC.title = strDeviceName;
    [self.navigationController pushViewController:subVC animated:YES];
    [uart BD_enableTransparentData:YES];
}

//连接失败回调
- (void)BR_connectFail:(int)nFAILETYPE
{
    [self ScanDevice];
    tmr_ScanDevice = [NSTimer scheduledTimerWithTimeInterval:2.0f target:self selector:@selector(ScanDevice) userInfo:nil repeats:YES];
    [loadView setHidden:NO];
    [self ClearTableViewData];
}

//断开连接回调
- (void)BR_didDisconnect
{
    [self ClearTableViewData];
    [self.navigationController popToRootViewControllerAnimated:YES];
}

#pragma mark - UITableView Delegate & DataSource Method
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return deviceArray.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *cellIdentifier = @"cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:cellIdentifier];
    
    if (cell == nil)
    {
        cell = [tableView dequeueReusableCellWithIdentifier:cellIdentifier];
    }
    
    cell.textLabel.text = [[deviceArray[indexPath.row] componentsSeparatedByString:@","] objectAtIndex:0];
    
    //detail显示设备uuid
    cell.detailTextLabel.text = deviceUUIDArray[indexPath.row];
    
    return cell;
}

//点击开始连接,根据返回设备列表中的uuid来连接,速度更快
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [tmr_ScanDevice invalidate];
    tmr_ScanDevice = nil;
    //在这里循环连接5次,如果连上,不继续连接;如果3次没连上,重新开始搜索,防止定时器关闭之后一直不搜索设备
    nConnectCount = 0;
    [NSTimer scheduledTimerWithTimeInterval:.5f target:self selector:@selector(connectWithIndex:) userInfo:[NSNumber numberWithInt:indexPath.row] repeats:NO];
    strDeviceName = [[deviceArray[indexPath.row] componentsSeparatedByString:@","] objectAtIndex:0];
}

//根据scanindex来连接设备
- (void)connectWithIndex:(NSTimer *)timer
{
    if ([uart BD_getIsConnected]) return;
    //NSLog(@"%d", [timer.userInfo intValue]);
    if (nConnectCount < 5)
    {
        [uart BD_initConnectWithScanIndex:[timer.userInfo intValue]];
        nConnectCount++;
        [NSTimer scheduledTimerWithTimeInterval:.5f target:self selector:@selector(connectWithIndex:) userInfo:timer.userInfo repeats:NO];
    }
    else
    {
        tmr_ScanDevice = [NSTimer scheduledTimerWithTimeInterval:2.0f target:self selector:@selector(ScanDevice) userInfo:nil repeats:YES];
    }
}

@end
